plot — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# plot

FermiSurface.plot(mode: str, interpolation=500)

  This method plots the 2d fermi surface along the z axis

  Only 2D layer geometry along z

  Parameters:

    - mode (str, optional) – This parameters sets the mode,

    - interpolation (int, optional) – The interpolation level, by default 500

  Returns:

    List[plots] – Returns a list of matplotlib.pyplot instances

  Raises:

    RuntimeError – Raise error if find energy was not called before plotting.